@@ -1,18 +1,6 @@
 "samplecube" <-
 function(X,pik,order=1,comment=TRUE,method=1) 
-#
-# return a balanced sample (a vector of 0 and 1)
-# X is the matrix of balancing variables
-# pik is the vector of inclusion probabilities
-# order = 1 if the file is sorted randomly
-#          = 2 if the file is not sorted
-#          = 3 if the file is sorted in the decreasing order of the inclusion probabilities
-#  comment =TRUE to have comments and FALSE otherwise
-#  method = 1 for a landing phase by linear programming
-#           2 for a landing phase by suppression of variables
-######################################################
 {
-##########################################################
 EPS = 1e-11
 N=length(pik)
 if(is.array(X)!=TRUE) X=array(X,c(N,length(X)/N)) 
@@ -45,7 +33,6 @@ else
       pikfin = pikstar
       for(i in 1:N) if(runif(1)<pikfin[i]) pikfin[i]=1
 }
-#######################################################
 if (comment == TRUE) {
         A <- X[pik > EPS, ]/pik[pik > EPS]
         TOT = t(A) %*% pik[pik > EPS]
@@ -54,10 +41,10 @@ if (comment == TRUE) {
         cat("\n\nQUALITY OF BALANCING\n")
         if(is.null(colnames(X)))  Vn = as.character(1:length(TOT)) else Vn=colnames(X);
         for(i in 1:length(TOT)) if(Vn[i]=="") Vn[i]=as.character(i)
-	ddddd = data.frame(TOTALS = c(TOT), 
+	d = data.frame(TOTALS = c(TOT), 
         HorvitzThompson_estimators = c(EST), Relative_deviation = c(DEV))
-        rownames(ddddd)<-Vn
-        print(ddddd)
+        rownames(d)<-Vn
+        print(d)
     }
     round(pikfin)
 }
